
[![CI](https://github.com/Hubro/tree-sitter-robot/actions/workflows/ci.yaml/badge.svg)](https://github.com/Hubro/tree-sitter-robot/actions/workflows/ci.yaml)

# tree-sitter-robot

Tree-sitter parser for Robot Framework files.

Includes queries for syntax highlighting, indentation and folding.
